==> libetpan_0.36.orig.tar.gz: libetpan-0.36/src/driver/tools/mailthread_types.h <==
/*
 * libEtPan! -- a mail stuff library
 *
 * Copyright (C) 2001, 2005 - DINH Viet Hoa
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the libEtPan! project nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHORS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/*
 * $Id: mailthread_types.h,v 1.8 2004/11/21 21:53:35 hoa Exp $
 */

#ifndef MAILTHREAD_TYPES_H

#define MAILTHREAD_TYPES_H

#ifdef __cplusplus
extern "C" {
#endif

#include <libetpan/maildriver_types.h>
#include <libetpan/mailmessage_types.h>

/*
  This is the type of tree construction to apply.
*/

enum {
  MAIL_THREAD_REFERENCES,            /* this is threading using
                                        References fields only) */
  MAIL_THREAD_REFERENCES_NO_SUBJECT, /* this is threading using References
                                        fields, then subject */
  MAIL_THREAD_ORDEREDSUBJECT,        /* this is threading using only subject */
  MAIL_THREAD_NONE,                  /* no thread */
};

#ifdef __cplusplus
}
#endif

#endif

==> libetpan_0.48.orig.tar.gz: libetpan-0.48/src/driver/tools/mailthread_types.h <==
/*
 * libEtPan! -- a mail stuff library
 *
 * Copyright (C) 2001, 2005 - DINH Viet Hoa
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the libEtPan! project nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHORS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/*
 * $Id: mailthread_types.h,v 1.9 2006/05/22 13:39:40 hoa Exp $
 */

#ifndef MAILTHREAD_TYPES_H

#define MAILTHREAD_TYPES_H

#ifdef __cplusplus
extern "C" {
#endif

#include <libetpan/maildriver_types.h>
#include <libetpan/mailmessage_types.h>

/*
  This is the type of tree construction to apply.
*/

enum {
  MAIL_THREAD_REFERENCES,            /* this is threading using
                                        References fields only) */
  MAIL_THREAD_REFERENCES_NO_SUBJECT, /* this is threading using References
                                        fields, then subject */
  MAIL_THREAD_ORDEREDSUBJECT,        /* this is threading using only subject */
  MAIL_THREAD_NONE                   /* no thread */
};

#ifdef __cplusplus
}
#endif

#endif
